#!/usr/bin/env python3
"""
Author : Xinyuan Chen <45612704+tddschn@users.noreply.github.com>
Date   : 2024-04-14
Purpose: AI Studio Prevew CSV to HTML
"""

import argparse
from pathlib import Path
from google_ai_studio_utils.utils import conversation_to_html, parse_csv_to_conversation


def get_args():
    """Get command-line arguments"""

    parser = argparse.ArgumentParser(
        description='AI Studio Prevew CSV to HTML',
        formatter_class=argparse.ArgumentDefaultsHelpFormatter)
    
    parser.add_argument('path', metavar='path', type=Path, help='Path to CSV file generated by https://github.com/tddschn/userscripts/blob/master/google-ai-studio-export-conversation-to-csv-user.js')
    parser.add_argument('-t', '--title', help='Title of the HTML page', metavar='title')
    parser.add_argument('-f', '--font', help='Font-Family of the HTML page', metavar='font')


    return parser.parse_args()


def main():
    """Make a jazz noise here"""

    args = get_args()
    convo = parse_csv_to_conversation(args.path)
    kwargs = {}
    if args.title:
        kwargs['title'] = args.title
    if args.font:
        kwargs['font'] = args.font
    html = conversation_to_html(convo, **kwargs)
    print(html)
    
    


if __name__ == '__main__':
    main()
